.. image:: ../../imgs/ooipy_banner2.png
  :width: 700
  :alt: OOIPY Logo
  :align: left

Request Module
==============
This module provides the tools to download OOI data from the OOI Raw Data
Server.

Hydrophone
^^^^^^^^^^
    
.. automodule:: ooipy.request.hydrophone_request
    :members:

CTD
^^^
.. automodule:: ooipy.request.ctd_request
    :members: